@@ -1,27 +1,13 @@
 /*
-   This file is part of the KDE libraries
+    This file is part of the KDE libraries
 
-   Copyright (c) 1999 Matthias Hoelzer-Kluepfel <hoelzer@kde.org>
-   Copyright (c) 2001 Michael Goffioul <kdeprint@swing.be>
-   Copyright (C) 2004 Frans Englich <frans.englich@telia.com>
-   Copyright (C) 2009 Dario Freddi <drf@kde.org>
-   Copyright (C) 2015 Marco Martin <mart@kde.org>
-
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-FileCopyrightText: 1999 Matthias Hoelzer-Kluepfel <hoelzer@kde.org>
+    SPDX-FileCopyrightText: 2001 Michael Goffioul <kdeprint@swing.be>
+    SPDX-FileCopyrightText: 2004 Frans Englich <frans.englich@telia.com>
+    SPDX-FileCopyrightText: 2009 Dario Freddi <drf@kde.org>
+    SPDX-FileCopyrightText: 2015 Marco Martin <mart@kde.org>
 
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef CONFIGMODULE_H
@@ -29,8 +15,8 @@
 
 #include "quickaddons_export.h"
 
-#include <QVariant>
 #include <QObject>
+#include <QVariant>
 #include <QtQml>
 
 #include <KPluginMetaData>
@@ -40,8 +26,8 @@ class KAboutData;
 class QQuickItem;
 class QQmlEngine;
 
-namespace KQuickAddons {
-
+namespace KQuickAddons
+{
 class ConfigModulePrivate;
 
 /**
@@ -142,9 +128,9 @@ class QUICKADDONS_EXPORT ConfigModule : public QObject
     Q_PROPERTY(int columnWidth READ columnWidth WRITE setColumnWidth NOTIFY columnWidthChanged)
     Q_PROPERTY(int depth READ depth NOTIFY depthChanged)
     Q_PROPERTY(int currentIndex READ currentIndex WRITE setCurrentIndex NOTIFY currentIndexChanged)
+    Q_PROPERTY(int defaultsIndicatorsVisible READ defaultsIndicatorsVisible WRITE setDefaultsIndicatorsVisible NOTIFY defaultsIndicatorsVisibleChanged)
 
 public:
-
     /**
      * An enumeration type for the buttons used by this module.
      * You should only use Help, Default and Apply. The rest is obsolete.
@@ -156,7 +142,7 @@ public:
         NoAdditionalButton = 0,
         Help = 1,
         Default = 2,
-        Apply = 4
+        Apply = 4,
     };
     Q_ENUM(Button)
     Q_DECLARE_FLAGS(Buttons, Button)
@@ -226,9 +212,8 @@ public:
      */
     QString authActionName() const;
 
-
     /**
-     * @deturn the qml engine that built the main config UI
+     * @return the qml engine that built the main config UI
      */
     QQmlEngine *engine() const;
 
@@ -244,7 +229,7 @@ public:
      */
     QString errorString() const;
 
-//QML property accessors
+    // QML property accessors
 
     /**
      * @return The main UI for this configuration module. It's a QQuickItem coming from
@@ -253,6 +238,13 @@ public:
      */
     QQuickItem *mainUi();
 
+    /*
+     * @return a subpage at a given depth
+     * @note This does not include the mainUi. i.e a depth of 2 is a mainUi and one subPage
+     * at index 0
+     */
+    QQuickItem *subPage(int index) const;
+
     /**
      * Sets the quick help.
      */
@@ -317,7 +309,6 @@ public:
      */
     Buttons buttons() const;
 
-
     /**
      * Sets the RootOnly message.
      *
@@ -342,7 +333,6 @@ public:
      */
     QString rootOnlyMessage() const;
 
-
     /**
      * Change whether or not the RootOnly message should be shown.
      *
@@ -365,7 +355,6 @@ public:
      */
     bool useRootOnlyMessage() const;
 
-
     /**
      * @brief Set if the module's save() method requires authorization to be executed.
      *
@@ -421,7 +410,7 @@ public:
 
     /**
      * @returns how many pages this kcm has.
-     * It is guaranteed to be at least 1 9the main ui) plus how many times a new page has been pushed without pop
+     * It is guaranteed to be at least 1 (the main ui) plus how many times a new page has been pushed without pop
      */
     int depth() const;
 
@@ -439,6 +428,12 @@ public:
 
     static ConfigModule *qmlAttachedProperties(QObject *object);
 
+    /**
+     * @returns defaultness indicator visibility
+     * @since 5.73
+     */
+    bool defaultsIndicatorsVisible() const;
+
 public Q_SLOTS:
     /**
      * Load the configuration data into the module.
@@ -480,7 +475,7 @@ public Q_SLOTS:
     virtual void defaults();
 
     /**
-     * Push a new sub page in the KCM hyerarchy: pages will be seen as a Kirigami PageRow
+     * Push a new sub page in the KCM hierarchy: pages will be seen as a Kirigami PageRow
      * @since 5.50
      */
     void push(const QString &fileName, const QVariantMap &propertyMap = QVariantMap());
@@ -491,11 +486,31 @@ public Q_SLOTS:
     void push(QQuickItem *item);
 
     /**
-     * pop the last page of the KCM hyerarchy
+     * pop the last page of the KCM hierarchy
      * @since 5.50
      */
     void pop();
 
+    /**
+     * Ask the shell to show a passive notification
+     * @param message The message text to display
+     * @param timeout (optional) the timeout, either in milliseconds or the strings "short" and "long"
+     * @param actionText (optional) The notification can have a button with this text
+     * @param callBack (optional) If actionText is set and callBack is a JavaScript function, it will be called when the use clicks the button.
+     * @since 5.68
+     */
+    void showPassiveNotification(const QString &message,
+                                 const QVariant &timeout = QVariant(),
+                                 const QString &actionText = QString(),
+                                 const QJSValue &callBack = QJSValue());
+
+    /**
+     * Change defaultness indicator visibility
+     * @param visible
+     * @since 5.73
+     */
+    void setDefaultsIndicatorsVisible(bool visible);
+
 Q_SIGNALS:
 
     /**
@@ -503,7 +518,7 @@ Q_SIGNALS:
      */
     void authActionNameChanged();
 
-    //QML NOTIFY signaling
+    // QML NOTIFY signaling
     /**
      * Buttons to display changed.
      */
@@ -563,7 +578,7 @@ Q_SIGNALS:
      * Emitted when a sub page is popped
      * @since 5.50
      */
-    //RFC: page argument?
+    // RFC: page argument?
     void pageRemoved();
 
     /**
@@ -584,6 +599,18 @@ Q_SIGNALS:
      */
     void depthChanged(int index);
 
+    /**
+     * Emitted when the kcm wants the shell to display a passive notification
+     * @since 5.68
+     */
+    void passiveNotificationRequested(const QString &message, const QVariant &timeout, const QString &actionText, const QJSValue &callBack);
+
+    /**
+     * Emitted when kcm need to display indicators for field with non default value
+     * @since 5.73
+     */
+    void defaultsIndicatorsVisibleChanged();
+
 private:
     ConfigModulePrivate *const d;
 };
@@ -593,5 +620,4 @@ private:
 Q_DECLARE_OPERATORS_FOR_FLAGS(KQuickAddons::ConfigModule::Buttons)
 QML_DECLARE_TYPEINFO(KQuickAddons::ConfigModule, QML_HAS_ATTACHED_PROPERTIES)
 
-#endif //ConfigModule_H
-
+#endif // ConfigModule_H
